ebenezer package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ebenezer.commands
   ebenezer.config
   ebenezer.core
   ebenezer.widgets

Module contents
---------------

.. automodule:: ebenezer
   :members:
   :undoc-members:
   :show-inheritance:
